@@ -76,9 +76,22 @@ class Install(MethodsInterface):
         else:
             self.clVars = datavars
 
+    def canInstallGrub2(self, target):
+        """Check that system has grub2 in current and installed system"""
+        if self.clVars.Get('os_grub2_path'):
+            return bool([x for x in listDirectory('/var/db/pkg/sys-boot') 
+                if (x.startswith('grub-1.99') or x.startswith('grub-2'))])
+        return False
+
     def prepareBoot(self, target_distr):
-        """Prepare flash for boot"""
-        self.installSyslinuxBootloader(target_distr)
+        """Prepare system for boot"""
+        if self.clVars.Get('os_install_root_type') == "flash":
+            self.installSyslinuxBootloader(target_distr)
+        else:
+            if self.canInstallGrub2(target_distr):
+                self.installGrub2Bootloader(target_distr)
+            else:
+                self.installLegacyGrubBootloader(target_distr)
         return True
 
     def setActivePartition(self, partition):
